==> jei-1.21.1-fabric-19.27.0.337-sources.jar: mezz/jei/fabric/mixin/MinecraftMixin.java <==
package mezz.jei.fabric.mixin;

import mezz.jei.fabric.events.JeiLifecycleEvents;
import net.minecraft.class_1060;
import net.minecraft.class_310;
import net.minecraft.class_3304;
import net.minecraft.class_437;
import net.minecraft.class_542;
import org.spongepowered.asm.mixin.Final;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_310.class)
public class MinecraftMixin {
	@Shadow
	@Final
	private class_3304 resourceManager;

	@Shadow
	@Final
	private class_1060 textureManager;

	@Inject(
		method = "<init>(Lnet/minecraft/client/main/GameConfig;)V",
		at = @At(
			value = "INVOKE",
			target = "Lnet/minecraft/client/ResourceLoadStateTracker;startReload(Lnet/minecraft/client/ResourceLoadStateTracker$ReloadReason;Ljava/util/List;)V",
			ordinal = 0
		)
	)
	public void beforeInitialResourceReload(class_542 gameConfig, CallbackInfo ci) {
		JeiLifecycleEvents.REGISTER_RESOURCE_RELOAD_LISTENER.invoker()
				.registerResourceReloadListener(resourceManager, textureManager);
	}

	@Inject(
		method = "clearClientLevel(Lnet/minecraft/client/gui/screens/Screen;)V",
		at = @At(
			value = "INVOKE",
			target = "Lnet/minecraft/client/renderer/GameRenderer;resetData()V",
			ordinal = 0,
			shift = At.Shift.AFTER
		)
	)
	public void clearLevel(class_437 screen, CallbackInfo ci) {
		JeiLifecycleEvents.GAME_STOP.invoker().run();
	}
}

==> jei-1.21.10-fabric-26.2.0.30-sources.jar: mezz/jei/fabric/mixin/MinecraftMixin.java <==
package mezz.jei.fabric.mixin;

import mezz.jei.fabric.events.JeiLifecycleEvents;
import net.minecraft.class_1060;
import net.minecraft.class_310;
import net.minecraft.class_3304;
import net.minecraft.class_437;
import net.minecraft.class_542;
import org.spongepowered.asm.mixin.Final;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_310.class)
public class MinecraftMixin {
	@Shadow
	@Final
	private class_3304 resourceManager;

	@Shadow
	@Final
	private class_1060 textureManager;

	@Inject(
		method = "<init>(Lnet/minecraft/client/main/GameConfig;)V",
		at = @At(
			value = "INVOKE",
			target = "Lnet/minecraft/client/ResourceLoadStateTracker;startReload(Lnet/minecraft/client/ResourceLoadStateTracker$ReloadReason;Ljava/util/List;)V",
			ordinal = 0
		)
	)
	public void beforeInitialResourceReload(class_542 gameConfig, CallbackInfo ci) {
		JeiLifecycleEvents.REGISTER_RESOURCE_RELOAD_LISTENER.invoker()
				.registerResourceReloadListener(resourceManager, textureManager);
	}

	@Inject(
		method = "disconnect(Lnet/minecraft/client/gui/screens/Screen;Z)V",
		at = @At(
			value = "INVOKE",
			target = "Lnet/minecraft/client/renderer/GameRenderer;resetData()V",
			ordinal = 0,
			shift = At.Shift.AFTER
		)
	)
	public void disconnect(class_437 nextScreen, boolean keepResourcePacks, CallbackInfo ci) {
		JeiLifecycleEvents.GAME_STOP.invoker().run();
	}
}
